sqlobject.inheritance.tests.test_destroy_cascade module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_destroy_cascade module

class `sqlobject.inheritance.tests.test_destroy_cascade.` `SOTestCascade1`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `childName`
  property `dummy`
  `j` = so_test_cascade1
  `q` = so_test_cascade1
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'SOTestCascade2': <class 'sqlobject.inheritance.tests.test_destroy_cascade.SOTestCascade2'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_destroy_cascade.SOTestCascade1`

    `table` = 'so_test_cascade1'

class `sqlobject.inheritance.tests.test_destroy_cascade.` `SOTestCascade2`(**kw)

  Bases: `sqlobject.inheritance.tests.test_destroy_cascade.SOTestCascade1`

  property `c`
  property `cID`
  property `childName`
  property `dummy`
  `j` = so_test_cascade2
  `q` = so_test_cascade2
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'SOTestCascade2'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_destroy_cascade.SOTestCascade1`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_destroy_cascade.SOTestCascade2`

    `table` = 'so_test_cascade2'

class `sqlobject.inheritance.tests.test_destroy_cascade.` `SOTestCascade3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `dummy`
  `j` = so_test_cascade3
  `q` = so_test_cascade3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.inheritance.tests.test_destroy_cascade.SOTestCascade3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_cascade3'

`sqlobject.inheritance.tests.test_destroy_cascade.` `test_destroySelf`()